==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/firewall/firewall.pm <==
/* _dict.cc 03/05/1998 00.53.08 */
/* firewall.cc 02/03/2000 14.39.26 */
PUBLIC IPFW_RULE *IPFW_RULES::getitem (int no);
PROTECTED void IPFW_RULES::init (CONFDB *_db,
	 const char *key,
	 const char *key_active);
PUBLIC IPFW_RULES_FORWARD::IPFW_RULES_FORWARD (CONFDB *_db);
PUBLIC IPFW_RULES_INPUT::IPFW_RULES_INPUT (CONFDB *_db);
PUBLIC IPFW_RULES_OUTPUT::IPFW_RULES_OUTPUT (CONFDB *_db);
PUBLIC IPFW_RULES_ACCT::IPFW_RULES_ACCT (CONFDB *_db);
PROTECTED int IPFW_RULES::savek (const char *key,
	 const char *key_active);
PUBLIC int IPFW_RULES_FORWARD::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_FORWARD::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_FORWARD::newrule (const char *pt);
PUBLIC int IPFW_RULES_INPUT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_INPUT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_INPUT::newrule (const char *pt);
PUBLIC int IPFW_RULES_OUTPUT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_OUTPUT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_OUTPUT::newrule (const char *pt);
PUBLIC int IPFW_RULES_ACCT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_ACCT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_ACCT::newrule (const char *pt);
PROTECTED VIRTUAL void IPFW_RULES::initrules (void);
PUBLIC int IPFW_RULES::edit (void);
PUBLIC int IPFW_RULES_INPUT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_INPUT::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_INPUT::kernelok (void);
PUBLIC int IPFW_RULES_OUTPUT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_OUTPUT::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_FORWARD::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_FORWARD::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_ACCT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_ACCT::enable (bool, SSTRING *);
PUBLIC int IPFW_RULES_FORWARD::kernelok (void);
PUBLIC int IPFW_RULES_OUTPUT::kernelok (void);
PUBLIC int IPFW_RULES_ACCT::kernelok (void);
PROTECTED void IPFW_RULES_ACCT::initrules (void);
PUBLIC int IPFW_RULES::setup (bool doit, SSTRING *collect);
/* fwstatus.cc 12/12/1999 22.30.32 */
/* ipfw.cc 02/03/2000 11.15.58 */
/* ipfwrule.cc 02/03/2000 14.47.14 */
PUBLIC IPFW_SOLVED::IPFW_SOLVED (void);
PROTECTED IPFW_RULE::IPFW_RULE (void);
PUBLIC int IPFW_RULE::getweight (void);
PUBLIC bool IPFW_RULE::is_bidir (void);
PROTECTED IPFW_RULEP::IPFW_RULEP (void);
PROTECTED IPFW_RULE::IPFW_RULE (const char *&buf);
PROTECTED const char *IPFW_RULEP::extract_newf (const char *buf);
PROTECTED IPFW_RULEP::IPFW_RULEP (const char *&buf);
PUBLIC IPFW_RULE_FORWARD::IPFW_RULE_FORWARD (const char *buf);
PUBLIC IPFW_RULE_FORWARD::IPFW_RULE_FORWARD (void);
PUBLIC IPFW_RULE_OUTPUT::IPFW_RULE_OUTPUT (const char *buf);
PUBLIC IPFW_RULE_OUTPUT::IPFW_RULE_OUTPUT (void);
PUBLIC IPFW_RULE_INPUT::IPFW_RULE_INPUT (const char *buf);
PUBLIC IPFW_RULE_INPUT::IPFW_RULE_INPUT (void);
PUBLIC IPFW_RULE_ACCT::IPFW_RULE_ACCT (const char *buf);
PUBLIC IPFW_RULE_ACCT::IPFW_RULE_ACCT (void);
PROTECTED void IPFW_RULEP::append_newf (char *buf);
PROTECTED void IPFW_RULE::savek (char *buf);
PUBLIC void IPFW_RULE_FORWARD::save (CONFDB *db);
PUBLIC void IPFW_RULE_INPUT::save (CONFDB *db);
PUBLIC void IPFW_RULE_OUTPUT::save (CONFDB *db);
PUBLIC void IPFW_RULE_ACCT::save (CONFDB *db);
PUBLIC void IPFW_RULE::present (char *buf1,
	 int size1,
	 char *buf2,
	 int size2);
PUBLIC int IPFW_RULE::solve (IPFW_SRC&f,
	 FWINFO_API *tbapi[],
	 int nbapi);
PUBLIC int IPFW_RULE::nbbitmask_from (void);
PUBLIC int IPFW_RULE::nbbitmask_to (void);
PUBLIC int IPFW_RULE::cmp_gen_to (IPFW_RULE *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULE::cmp_gen_from (IPFW_RULE *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULEP::cmp_policy_to (IPFW_RULEP *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULEP::cmp_policy_from (IPFW_RULEP *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULE_INPUT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_INPUT::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_OUTPUT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_OUTPUT::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_FORWARD::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_FORWARD::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_ACCT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_ACCT::cmp_to (IPFW_RULE *r);
PRIVATE int IPFW_RULE::diacheck (IPFW_SRC&s, int &nof);
PROTECTED void IPFW_RULE::setup_top (DIALOG&dia, DIALOG_CONTEXT&ctx);
PROTECTED void IPFW_RULE::setup_interface (DIALOG&dia,
	 const char *devtitle,
	 SSTRING&interface);
PROTECTED void IPFW_RULE::setup_from (DIALOG&dia,
	 DIALOG_CONTEXT&ctx,
	 const char *devtitle);
PROTECTED void IPFW_RULE::setup_to (DIALOG&dia,
	 DIALOG_CONTEXT&ctx,
	 const char *devtitle);
PROTECTED void IPFW_RULE::setup_features (DIALOG&dia,
	 DIALOG_CONTEXT&);
PUBLIC int IPFW_RULE::editk (DIALOG&dia,
	 const char *title,
	 DIALOG_CONTEXT&ctx);
PROTECTED void IPFW_RULEP::setpolicy (DIALOG&dia);
PUBLIC int IPFW_RULE_FORWARD::edit (void);
PUBLIC int IPFW_RULE_OUTPUT::edit (void);
PUBLIC int IPFW_RULE_INPUT::edit (void);
PUBLIC int IPFW_RULE_ACCT::edit (void);
PRIVATE int IPFW_RULE::setupone (int policy,
	 const IPFW_SRC&f,
	 const IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 bool syn_packets,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE::setup (int policy,
	 const IPFW_SRC&f,
	 const IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PROTECTED int IPFW_RULEP::setup (IPFW_SRC&f,
	 IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_FORWARD::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_FORWARD::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_OUTPUT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_OUTPUT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_INPUT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_INPUT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_ACCT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_ACCT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
/* mod_firewall.cc 12/12/1999 22.28.02 */
PUBLIC MODULE_firewall::MODULE_firewall (void);
PUBLIC void MODULE_firewall::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_firewall::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_firewall::dohtml (const char *key);
PUBLIC int MODULE_firewall::probe (int level, int , bool);
PUBLIC int MODULE_firewall::message (const char *msg,
	 int ,
	 const char *[]);
PUBLIC int MODULE_firewall::execmain (int argc, char *argv[]);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/firewall/firewall.pm <==
/* _dict.cc 03/05/1998 00.53.08 */
/* chains.tlcc 01/06/2001 11.05.28 */
PUBLIC CHAIN::CHAIN (const char *_name, const char *_dispatch);
PUBLIC void CHAIN::confirm (void);
PUBLIC void CHAIN::addcmd (const char *cmd, bool _no_order);
PUBLIC void CHAIN::addoldcmd (const char *cmd);
PUBLIC CHAINS::CHAINS (void);
PUBLIC CHAIN *CHAINS::getitem (int no)const;
PUBLIC void CHAINS::add (CHAIN *c);
PUBLIC CHAIN *CHAINS::getitem (const char *dispatch)const;
PUBLIC int CHAINS::lookup (const char *dispatch)const;
PUBLIC void CHAINS::setfail (void);
PUBLIC void CHAINS::reset (void);
PUBLIC void CHAINS::loadold (void);
PUBLIC int CHAINS::updkernel (void);
/* firewall.cc 12/05/2001 23.07.22 */
PUBLIC IPFW_RULE *IPFW_RULES::getitem (int no);
PROTECTED void IPFW_RULES::init (CONFDB *_db,
	 const char *key,
	 const char *key_active);
PUBLIC IPFW_RULES_FORWARD::IPFW_RULES_FORWARD (CONFDB *_db);
PUBLIC IPFW_RULES_INPUT::IPFW_RULES_INPUT (CONFDB *_db);
PUBLIC IPFW_RULES_OUTPUT::IPFW_RULES_OUTPUT (CONFDB *_db);
PUBLIC IPFW_RULES_ACCT::IPFW_RULES_ACCT (CONFDB *_db);
PROTECTED int IPFW_RULES::savek (const char *key,
	 const char *key_active);
PUBLIC int IPFW_RULES_FORWARD::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_FORWARD::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_FORWARD::newrule (const char *pt);
PUBLIC int IPFW_RULES_INPUT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_INPUT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_INPUT::newrule (const char *pt);
PUBLIC int IPFW_RULES_OUTPUT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_OUTPUT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_OUTPUT::newrule (const char *pt);
PUBLIC int IPFW_RULES_ACCT::save (void);
PROTECTED IPFW_RULE *IPFW_RULES_ACCT::newrule (void);
PROTECTED IPFW_RULE *IPFW_RULES_ACCT::newrule (const char *pt);
PROTECTED VIRTUAL void IPFW_RULES::initrules (void);
PUBLIC int IPFW_RULES::edit (void);
PUBLIC int IPFW_RULES_INPUT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_INPUT::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_OUTPUT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_OUTPUT::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_FORWARD::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_FORWARD::enable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_ACCT::disable (bool doit, SSTRING *collect);
PUBLIC int IPFW_RULES_ACCT::enable (bool, SSTRING *);
PROTECTED void IPFW_RULES_ACCT::initrules (void);
PUBLIC int IPFW_RULES::setup (FIREWALL_SECTION section,
	 bool doit,
	 SSTRING *collect);
/* flushchains.cc 10/05/2001 13.16.48 */
/* fwstatus.cc 12/05/2001 23.25.24 */
/* ipfw.cc 01/06/2001 11.05.24 */
/* ipfwrule.cc 01/06/2001 11.01.12 */
PUBLIC IPFW_SOLVED_TRIPLET::IPFW_SOLVED_TRIPLET (const char *_ip,
	 const char *_mask,
	 const char *_interface,
	 bool _not_flag);
PUBLIC IPFW_SOLVED_TRIPLET *IPFW_SOLVED_TRIPLETS::getitem (int no)const;
PUBLIC IPFW_SOLVED_TRIPLET *IPFW_SOLVED_TRIPLETS::add (const char *_ip,
	 const char *_mask,
	 const char *_interface,
	 bool not_flag);
PUBLIC IPFW_SOLVED::IPFW_SOLVED (void);
PROTECTED IPFW_RULE::IPFW_RULE (void);
PUBLIC int IPFW_RULE::getweight (void);
PUBLIC bool IPFW_RULE::is_bidir (void);
PROTECTED IPFW_RULEP::IPFW_RULEP (void);
PROTECTED IPFW_RULE::IPFW_RULE (const char *&buf);
PROTECTED const char *IPFW_RULEP::extract_newf (const char *buf);
PROTECTED const char *IPFW_RULEP::extract_chain (const char *buf);
PROTECTED IPFW_RULEP::IPFW_RULEP (const char *&buf);
PUBLIC IPFW_RULE_FORWARD::IPFW_RULE_FORWARD (const char *buf);
PUBLIC IPFW_RULE_FORWARD::IPFW_RULE_FORWARD (void);
PUBLIC IPFW_RULE_OUTPUT::IPFW_RULE_OUTPUT (const char *buf);
PUBLIC IPFW_RULE_OUTPUT::IPFW_RULE_OUTPUT (void);
PUBLIC IPFW_RULE_INPUT::IPFW_RULE_INPUT (const char *buf);
PUBLIC IPFW_RULE_INPUT::IPFW_RULE_INPUT (void);
PUBLIC IPFW_RULE_ACCT::IPFW_RULE_ACCT (const char *buf);
PUBLIC IPFW_RULE_ACCT::IPFW_RULE_ACCT (void);
PROTECTED void IPFW_RULEP::append_newf (char *buf);
PROTECTED void IPFW_RULEP::append_chain (char *buf);
PROTECTED void IPFW_RULE::savek (char *buf);
PUBLIC void IPFW_RULE_FORWARD::save (CONFDB *db);
PUBLIC void IPFW_RULE_INPUT::save (CONFDB *db);
PUBLIC void IPFW_RULE_OUTPUT::save (CONFDB *db);
PUBLIC void IPFW_RULE_ACCT::save (CONFDB *db);
PUBLIC void IPFW_RULE::present (char *buf1,
	 int size1,
	 char *buf2,
	 int size2);
PUBLIC int IPFW_RULE::solve (IPFW_SRC&f,
	 FWINFO_API *tbapi[],
	 int nbapi);
PUBLIC int IPFW_RULE::nbbitmask_from (void);
PUBLIC int IPFW_RULE::nbbitmask_to (void);
PUBLIC int IPFW_RULE::cmp_gen_to (IPFW_RULE *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULE::cmp_gen_from (IPFW_RULE *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULEP::cmp_policy_to (IPFW_RULEP *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULEP::cmp_policy_from (IPFW_RULEP *r,
	 int masq1,
	 int masq2,
	 int redir1,
	 int redir2);
PUBLIC int IPFW_RULE_INPUT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_INPUT::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_OUTPUT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_OUTPUT::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_FORWARD::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_FORWARD::cmp_to (IPFW_RULE *r);
PUBLIC int IPFW_RULE_ACCT::cmp_from (IPFW_RULE *r);
PUBLIC int IPFW_RULE_ACCT::cmp_to (IPFW_RULE *r);
PRIVATE int IPFW_RULE::diacheck (IPFW_SRC&s, int &nof);
PROTECTED void IPFW_RULE::setup_top (DIALOG&dia, DIALOG_CONTEXT&ctx);
PROTECTED void IPFW_RULE::setup_interface (DIALOG&dia,
	 const char *devtitle,
	 SSTRING&interface);
PROTECTED void IPFW_RULE::setup_host (DIALOG&dia, SSTRING&host);
PROTECTED void IPFW_RULE::setup_from (DIALOG&dia,
	 DIALOG_CONTEXT&ctx,
	 const char *devtitle);
PROTECTED void IPFW_RULE::setup_to (DIALOG&dia,
	 DIALOG_CONTEXT&ctx,
	 const char *devtitle);
PROTECTED void IPFW_RULE::setup_features (DIALOG&dia,
	 DIALOG_CONTEXT&);
PUBLIC int IPFW_RULE::editk (DIALOG&dia,
	 const char *title,
	 DIALOG_CONTEXT&ctx);
PROTECTED void IPFW_RULEP::setpolicy (DIALOG&dia);
PUBLIC int IPFW_RULE_FORWARD::edit (void);
PUBLIC int IPFW_RULE_OUTPUT::edit (void);
PUBLIC int IPFW_RULE_INPUT::edit (void);
PUBLIC int IPFW_RULE_ACCT::edit (void);
PRIVATE int IPFW_RULE::setupone (int policy,
	 const IPFW_SRC&f,
	 const IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 const char *redirhost,
	 bool syn_packets,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE::setup (int policy,
	 const IPFW_SRC&f,
	 const IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 const char *redirhost,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PROTECTED int IPFW_RULEP::setup (IPFW_SRC&f,
	 IPFW_SRC&t,
	 FWTYPE type,
	 const char *redirport,
	 const char *redirhost,
	 bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_FORWARD::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_FORWARD::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_OUTPUT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_OUTPUT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_INPUT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_INPUT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_ACCT::setup_left (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
PUBLIC int IPFW_RULE_ACCT::setup_right (bool doit,
	 SSTRING *collect,
	 SSTRING&errmsg);
/* mod_firewall.cc 12/05/2001 23.07.54 */
PUBLIC MODULE_firewall::MODULE_firewall (void);
PUBLIC void MODULE_firewall::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_firewall::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_firewall::dohtml (const char *key);
PUBLIC int MODULE_firewall::probe (int level, int , bool);
PUBLIC int MODULE_firewall::message (const char *msg,
	 int ,
	 const char *[]);
PUBLIC int MODULE_firewall::execmain (int argc, char *argv[], bool);
